@@ -64,7 +64,7 @@ sn_sv gcli_config_get_base(struct gcli_ctx *ctx);
 gcli_forge_type gcli_config_get_forge_type(struct gcli_ctx *ctx);
 sn_sv gcli_config_get_override_default_account(struct gcli_ctx *ctx);
 bool gcli_config_pr_inhibit_delete_source_branch(struct gcli_ctx *ctx);
-void gcli_config_get_repo(struct gcli_ctx *ctx, char const **, char const **);
+int gcli_config_get_repo(struct gcli_ctx *ctx, char const **, char const **);
 int gcli_config_have_colours(struct gcli_ctx *ctx);
 struct gcli_config_entries const *gcli_config_get_section_entries(
 	struct gcli_ctx *ctx, char const *section_name);
