@@ -59,8 +59,8 @@ int gitlab_issue_assign(struct gcli_ctx *ctx, char const *owner,
                         char const *assignee);
 
 int gitlab_perform_submit_issue(struct gcli_ctx *ctx,
-                                struct gcli_submit_issue_options opts,
-                                struct gcli_fetch_buffer *out);
+                                struct gcli_submit_issue_options *opts,
+                                struct gcli_issue *out);
 
 int gitlab_issue_add_labels(struct gcli_ctx *ctx, char const *owner,
                             char const *repo, gcli_id issue,
