@@ -38,6 +38,8 @@
 
 #include <pdjson/pdjson.h>
 
+#include <templates/github/issues.h>
+
 int
 gitea_issues_search(struct gcli_ctx *ctx, char const *owner, char const *repo,
                     struct gcli_issue_fetch_details const *details,
@@ -46,6 +48,13 @@ gitea_issues_search(struct gcli_ctx *ctx, char const *owner, char const *repo,
 	char *url = NULL, *e_owner = NULL, *e_repo = NULL, *e_author = NULL,
 	     *e_label = NULL, *e_milestone = NULL, *e_query = NULL;
 
+	struct gcli_fetch_list_ctx fl = {
+		.listp = &out->issues,
+		.sizep = &out->issues_size,
+		.parse = (parsefn)(parse_github_issues),
+		.max = max,
+	};
+
 	if (details->milestone) {
 		char *tmp = gcli_urlencode(details->milestone);
 		e_milestone = sn_asprintf("&milestones=%s", tmp);
@@ -73,7 +82,7 @@ gitea_issues_search(struct gcli_ctx *ctx, char const *owner, char const *repo,
 	e_owner = gcli_urlencode(owner);
 	e_repo  = gcli_urlencode(repo);
 
-	url = sn_asprintf("%s/repos/%s/%s/issues?state=%s%s%s%s%s",
+	url = sn_asprintf("%s/repos/%s/%s/issues?type=issues&state=%s%s%s%s%s",
 	                  gcli_get_apibase(ctx),
 	                  e_owner, e_repo,
 	                  details->all ? "all" : "open",
@@ -89,7 +98,7 @@ gitea_issues_search(struct gcli_ctx *ctx, char const *owner, char const *repo,
 	free(e_owner);
 	free(e_repo);
 
-	return github_fetch_issues(ctx, url, max, out);
+	return gcli_fetch_list(ctx, url, &fl);
 }
 
 int
@@ -101,10 +110,11 @@ gitea_get_issue_summary(struct gcli_ctx *ctx, char const *owner,
 }
 
 int
-gitea_submit_issue(struct gcli_ctx *ctx, struct gcli_submit_issue_options opts,
-                   struct gcli_fetch_buffer *const out)
+gitea_submit_issue(struct gcli_ctx *const ctx,
+                   struct gcli_submit_issue_options *const opts,
+                   struct gcli_issue *const out)
 {
-	return github_perform_submit_issue(ctx,opts, out);
+	return github_perform_submit_issue(ctx, opts, out);
 }
 
 /* Gitea has closed, Github has close ... go figure */
